@@ -37,6 +37,7 @@
  * 22 Sep 01, tuorfa@yahoo.com: added function-level comment blocks 
  * 08 Oct 03, daved@physiol.usyd.edu.au: some type fixes
  * 29 Mar 05, daved@physiol.usyd.edu.au: changes requsted by ZT Smith
+ * 06 Jan 06, marcossamaral@terra.com.br: changes hash_stats function
  *--------------------------------------------------------------------*/
 
 #include <stdio.h>
@@ -82,14 +83,14 @@ hash_init ()
 
 /*========================================================================
  * Name:	hash_stats
- * Purpose:	Prints to stderr the number of words stored. This is all words,
+ * Purpose:	Return the number of words stored. This is all words,
  * 			including commands to RTF, NOT the number of printed words in
  * 			a given document.
  * Args:	None.
- * Returns:	None.
+ * Returns:	Number of words stored.
  *=======================================================================*/
 
-void
+unsigned long
 hash_stats ()
 {
 	int i;
@@ -97,7 +98,7 @@ hash_stats ()
 	for (i=0; i<256; i++) {
 		total += hash_length[i];
 	}
-	fprintf(stderr, "%lu words were hashed.\n", total);
+	return(total);
 }
 
 
