@@ -1,4 +1,3 @@
-
 /*=============================================================================
    GNU UnRTF, a command-line program to convert RTF documents to other formats.
    Copyright (C) 2000,2001,2004 by Zachary Smith
@@ -10,12 +9,12 @@
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
    The maintainer is reachable by electronic mail at daved@physiol.usyd.edu.au
 =============================================================================*/
@@ -36,6 +35,9 @@
  * 08 Oct 03, daved@physiol.usyd.edu.au: mac special character fixes
  * 29 Mar 05, daved@physiol.usyd.edu.au: changes requested by ZT Smith
  * 29 Mar 05, daved@physiol.usyd.edu.au: more unicode characters
+ * 21 Jul 05, daved@physiol.usyd.edu.au: added endash
+ * 19 Aug 05, ax2groin@arbornet.org: added more chars and changes to ANSI
+ * 05 Jan 06, marcossamaral@terra.com.br: fixed bugs #14982 and #14983
  *--------------------------------------------------------------------*/
 
 
@@ -49,7 +51,7 @@
 
 
 static char* ascii [96] = {
-	/* 0x20 */ " ", "!", "\"", "#", "$", "%", "&amp;", "'", 
+	/* 0x20 */ " ", "!", "&quot;", "#", "$", "%", "&amp;", "'", 
 	/* 0x28 */ "(", ")", "*", "+", ",", "-", ".", "/", 
 	/* 0x30 */ "0", "1", "2", "3", "4", "5", "6", "7", 
 	/* 0x38 */ "8", "9", ":", ";", "&lt;", "=", "&gt;", "?", 
@@ -60,12 +62,11 @@ static char* ascii [96] = {
 	/* 0x60 */ "`", "a", "b", "c", "d", "e", "f", "g", 
 	/* 0x68 */ "h", "i", "j", "k", "l", "m", "n", "o", 
 	/* 0x70 */ "p", "q", "r", "s", "t", "u", "v", "w", 
-	/* 0x78 */ "x", "y", "z", "{", "|", "}", "~", "", 
+	/* 0x78 */ "x", "y", "z", "{", "|", "}", "~", "" 
 };
 
 
 static char* ansi [] = {
-#if 1 /* daved - 0.19.6 */
 /* 0x78 */ "x",
 /* 0x79 */ "y",
 /* 0x7a */ "z",
@@ -73,13 +74,12 @@ static char* ansi [] = {
 /* 0x7c */ "|",
 /* 0x7d */ "}",
 /* 0x7e */ "~",
-/* 0x7f */ NULL,
-/* 0x80 */ NULL,
-/* 0x81 */ NULL,
-#endif
-/* 0x82 */ "&lsquor;",
+/* 0x7f */ "&#127;",
+/* 0x80 */ "&euro;", /* &#128; may be more widely recognized. */
+/* 0x81 */ "&#129;",
+/* 0x82 */ "&#130;", /* &lsquor; not implemented in any browsers I've seen. */
 /* 0x83 */ "&fnof;", 
-/* 0x84 */ "&ldquor;",
+/* 0x84 */ "&#132;", /* &ldquor; not implemented in any browsers I've seen. */
 /* 0x85 */ "&hellip;",
 /* 0x86 */ "&dagger;",
 /* 0x87 */ "&Dagger;",
@@ -88,27 +88,22 @@ static char* ansi [] = {
 /* 0x8a */ "&Scaron;",
 /* 0x8b */ "&lsaquo;",
 /* 0x8c */ "&OElig;",
-/* 0x8d */ NULL,
+/* 0x8d */ "&#141;",
 /* 0x8e */ "&Zcaron;",
-/* 0x8f */ NULL,
-/* 0x90 */ NULL,"`","'","``","''","&bull;","&ndash;","&mdash;",
-/* 0x98 */ NULL,
-/* 0x99 */ NULL,
+/* 0x8f */ "&#143;",
+/* 0x90 */ "&#144;", "&lsquo;", "&rsquo;", "&ldquo;", "&rdquo;", "&bull;", "&ndash;", "&mdash;", 
+/* 0x98 */ "&#152;",
+/* 0x99 */ "&trade;",
 /* 0x9a */ "&scaron;",
 /* 0x9b */ "&rsaquo;",	/* daved - 0.9.6 */
 /* 0x9c */ "&oelig;",
-/* 0x9d */ NULL,
+/* 0x9d */ "&#157;",
 /* 0x9e */ "&zcaron;",
 /* 0x9f */ "&Yuml;",
 /* 0xa0 */ "&nbsp;","&iexcl;","&cent;","&pound;","&curren;","&yen;","&brvbar;","&sect;",
 /* 0xa8 */ "&uml;","&copy;","&ordf;","&laquo;","&not;","&shy;","&reg;","&macr;",
-#if 0 /* daved 0.19.6 */
-/* 0xb0 */ "&deg;", "&plusmn;","&sup2;","&sup3;","&times;","&micro;","&para;","&middot;",
-/* 0xb8 */ "&divide;","&sup1", "&ordm;","&raquo", "&frac14", "&frac12;","&frac34;","&iquest;",
-#else
 /* 0xb0 */ "&deg;", "&plusmn;","&sup2;","&sup3;","&acute;","&micro;","&para;","&middot;",
-/* 0xb8 */ "&cedil;","&sup1", "&ordm;","&raquo", "&frac14", "&frac12;","&frac34;","&iquest;",
-#endif
+/* 0xb8 */ "&cedil;","&sup1", "&ordm;","&raquo;", "&frac14;", "&frac12;","&frac34;","&iquest;",
 /* 0xc0 */ "&Agrave;","&Aacute;","&Acirc;","&Atilde;","&Auml;","&Aring;","&AElig;","&Ccedil;",
 /* 0xc8 */ "&Egrave;","&Eacute;","&Ecirc;","&Euml;","&Igrave;","&Iacute;","&Icirc;","&Iuml;",
 /* 0xd0 */ "&ETH;","&Ntilde;","&Ograve;","&Oacute;","&Ocirc;","&Otilde;","&Ouml;","&times;",
@@ -116,7 +111,7 @@ static char* ansi [] = {
 /* 0xe0 */ "&agrave;","&aacute;","&acirc;","&atilde;","&auml;","&aring;","&aelig;","&ccedil;",
 /* 0xe8 */ "&egrave;","&eacute;","&ecirc;","&euml;","&igrave;","&iacute;","&icirc;","&iuml;",
 /* 0xf0 */ "&eth;","&ntilde;","&ograve;","&oacute;","&ocirc;","&otilde;","&ouml;","&divide;",
-/* 0xf8 */ "&oslash;","&ugrave;","&uacute;","&ucirc;","&uuml;","&yacute;","&thorn;","&yuml;",
+/* 0xf8 */ "&oslash;","&ugrave;","&uacute;","&ucirc;","&uuml;","&yacute;","&thorn;","&yuml;"
 };
 
 static char* mac [] = {
@@ -126,7 +121,7 @@ static char* mac [] = {
 /* 0xb8 */ NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 /* 0xc0 */ NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
 /* 0xc8 */ NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
-/* 0xd0 */ "&mdash;","&ndash;","&ldquo;","&rdquo;","&lquo;","&rquo;",
+/* 0xd0 */ "&mdash;","&ndash;","&ldquo;","&rdquo;","&lquo;","&rquo;"
 };
 
 #if 1 /* daved - 0.19.4 - unicode symbol character support */
@@ -1049,10 +1044,28 @@ html_init (void)
 	op->mac_first_char = 0xa4;
 	op->mac_last_char = 0xd5;
 
+#if 1 /* daved 0.19.8 */
+	op->chars.right_quote = "&rsquo;";
+	op->chars.left_quote = "&lsquo;";
+	op->chars.right_dbl_quote = "&rdquo;";
+	op->chars.left_dbl_quote = "&ldquo;";
+#else
 	op->chars.right_quote = "'";
 	op->chars.left_quote = "`";
-	op->chars.right_dbl_quote = "''";
-	op->chars.left_dbl_quote = "``";
+	op->chars.right_dbl_quote = "\"";
+	op->chars.left_dbl_quote = "\"";
+#endif
+#if 1 /* daved - 0.19.8 */
+	op->chars.endash = "&ndash;";
+	op->chars.emdash = "&mdash;";
+	op->chars.bullet = "&bull;";
+	op->chars.lessthan = "&lt;";
+	op->chars.greaterthan = "&gt;";
+	op->chars.amp = "&amp;";
+	op->chars.copyright = "&copy;";
+	op->chars.trademark = "&trade;";
+	op->chars.nonbreaking_space = "&nbsp;";
+#endif
 
 #if 1 /* daved - 0.19.4 - unicode symbol character support */
 	op->unisymbol1_first_char = 913;
@@ -1072,11 +1085,9 @@ html_init (void)
 #endif
 #if 1 /* daved - 0.19.5 - SYMBOL font support */
 	op->symbol_first_char = 60;
-        op->symbol_last_char = 254;
+    op->symbol_last_char = 254;
 	op->symbol_translation_table = symbol;
 #endif
 
 	return op;
 }
-
-
