@@ -40,6 +40,7 @@
  * 07 Jan 04, tuorfa@yahoo.com: removed broken PS support
  * 25 Sep 04, st001906@hrz1.hrz.tu-darmstadt.de: added stdlib.h for djgpp
  * 29 Mar 05, daved@physiol.usyd.edu.au: changes requested by ZT Smith
+ * 06 Jan 06, marcossamaral@terra.com.br: includes verbose mode 
  *--------------------------------------------------------------------*/
 
 
@@ -73,6 +74,8 @@ int simple_mode; /* TRUE => Output HTML without SPAN/DIV tags -- This would
 					as well. */
 int inline_mode; /* TRUE => Output HTML without HTML/BODY/HEAD -- This is
 					buggy. I've seen it output pages of </font> tags. */
+/* marcossamaral - 0.19.9 */
+int verbose_mode;  /* TRUE => Output additional informations about unrtf */
 
 
 OutputPersonality *op;
@@ -101,12 +104,13 @@ main (int argc, char **argv)
 	nopict_mode = debug_mode = dump_mode = inline_mode = FALSE;
 
 	/* Handle arguments */
-	if (argc < 2 || argc > 7) usage();
+	if (argc < 2 || argc > 8) usage();
 
 	for (i = 1; i < argc; i++) {
 		if (!strcmp("--dump", argv[i])) dump_mode = TRUE;
 		else if (!strcmp("-d", argv[i])) dump_mode = TRUE;
 		else if (!strcmp("--debug", argv[i])) debug_mode = TRUE;
+		else if (!strcmp("--verbose", argv[i])) verbose_mode = TRUE;
 		else if (!strcmp("--simple", argv[i])) simple_mode = TRUE;
 		else if (!strcmp("--html", argv[i])) output_format = OP_HTML;
 		else if (!strcmp("--text", argv[i])) output_format = OP_TEXT;
@@ -166,12 +170,14 @@ main (int argc, char **argv)
 
 	hash_init();
 
-	/* Program information. Perhaps this and other information below could
-	 *   be limited to a --verbose mode? */
-	fprintf(stderr, "This is UnRTF ");
-	fprintf(stderr, "version %s\n", PROGRAM_VERSION);
-	fprintf(stderr, "By Dave Davey and Marcos Serrou do Amaral\n");
-	fprintf(stderr, "Original Author: Zachary Smith\n");
+	
+	/* Program information */
+	if (verbose_mode || debug_mode) {
+		fprintf(stderr, "This is UnRTF ");
+		fprintf(stderr, "version %s\n", PROGRAM_VERSION);
+		fprintf(stderr, "By Dave Davey and Marcos Serrou do Amaral\n");
+		fprintf(stderr, "Original Author: Zachary Smith\n");
+	}
 
 	if (debug_mode) fprintf(stderr, "Debug mode.\n");
 	if (dump_mode) fprintf(stderr, "Dump mode.\n");
@@ -187,7 +193,7 @@ main (int argc, char **argv)
 			error_handler("Cannot open input file");
 	}
 
-	fprintf(stderr, "Processing %s...\n", path);
+	if (verbose_mode || debug_mode) fprintf(stderr, "Processing %s...\n", path); 
 
 	/* Keep track of lines processed. This is arbitrary to the user as
 	 *   RTF ignores newlines. May be helpful in error tracking. */
@@ -206,8 +212,13 @@ main (int argc, char **argv)
 
 	fclose(f);
 
-	fprintf(stderr, "Done.\n");
-	hash_stats();
+	/* marcossamaral - 0.19.9 */
+	if(verbose_mode || debug_mode) { 
+		unsigned long total=0;
+		total = hash_stats();
+		fprintf(stderr, "Done.\n");
+        	fprintf(stderr, "%lu words were hashed.\n", total);
+	}
 
 	if (debug_mode) {
 		fprintf(stderr, "Total memory allocated %ld bytes.\n", 
