@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
    The author is reachable by electronic mail at tuorfa@yahoo.com.
 =============================================================================*/
@@ -76,7 +76,7 @@ static int ungot_char3 = -1;
 static void my_unget_char (int ch)
 {
 	if (ungot_char>=0 && ungot_char2>=0 && ungot_char3>=0) 
-		error_handler ("more than 3 ungot chars");
+		error_handler("More than 3 ungot chars");
 
 	ungot_char3 = ungot_char2;
 	ungot_char2 = ungot_char;
@@ -138,7 +138,7 @@ static int my_getchar (FILE* f)
 					buffer_size /= 4;
 					read_buf = my_malloc (buffer_size);
 					if (!read_buf) 
-						error_handler ("cannot allocate read buffer");
+						error_handler("Cannot allocate read buffer");
 				}
 			}
 			read_buf_end = fread (read_buf, 1, buffer_size, f);
@@ -194,15 +194,15 @@ expand_word_buffer ()
 	char *new_ptr;
 	unsigned long old_length;
 	if (!input_str)
-		error_handler ("no input buffer allocated");
+		error_handler("No input buffer allocated");
 	old_length = current_max_length;
 	current_max_length *= 2;
 	new_ptr = my_malloc (current_max_length);
 	if (!new_ptr)
-		error_handler ("out of memory while resizing buffer");
+		error_handler("Out of memory while resizing buffer");
 	
 	memcpy (new_ptr, input_str, old_length);
-	my_free (input_str);
+	my_free(input_str);
 	input_str = new_ptr;
 	return TRUE;
 }
@@ -240,7 +240,7 @@ read_word (FILE *f)
 	 */
 	input_str = my_malloc (current_max_length);
 	if (!input_str)
-		error_handler("cannot allocate word storage");
+		error_handler("Cannot allocate word storage");
 
 	do {
 		ch = my_getchar(f);
@@ -296,19 +296,19 @@ read_word (FILE *f)
 			ix=2;
 			if(ix==current_max_length) {
 				if (!expand_word_buffer ())
-					error_handler("word too long");
+					error_handler("Word too long");
 			}
 			ch = my_getchar(f);
 			input_str[ix++]=ch;
 			if(ix==current_max_length) {
 				if (!expand_word_buffer ())
-					error_handler("word too long");
+					error_handler("Word too long");
 			}
 			ch = my_getchar(f);
 			input_str[ix++]=ch;
 			if(ix==current_max_length) {
 				if (!expand_word_buffer ())
-					error_handler("word too long");
+					error_handler("Word too long");
 			}
 			input_str[ix]=0;
 			return ix;
@@ -390,7 +390,7 @@ read_word (FILE *f)
 		input_str[ix++] = ch;
 		if (ix==current_max_length) {
 			if (!expand_word_buffer ())
-				error_handler("word too long");
+				error_handler("Word too long");
 		}
 		ch = my_getchar (f);
 	}
@@ -407,7 +407,7 @@ read_word (FILE *f)
 /*========================================================================
  * Name:	word_read
  * Purpose:	This is the recursive metareader which pieces together the 
- *		structure of Word objects.
+ *			structure of Word objects.
  * Args:	Input file.
  * Returns:	Tree of Word objects.
  *=======================================================================*/
@@ -421,52 +421,36 @@ word_read (FILE* f) {
 	CHECK_PARAM_NOT_NULL(f);
 
 	do {
-		if (!read_word(f)) {
+		if (!read_word(f))
 			return first_word;
-		}
-
 
 		if (input_str[0] == '{') {
 			/* Process subwords */
 
-#if 0
-printf ("processing subword...\n");
-#endif
-
 			/* Create a dummy word to point to a sublist */
-			new_word = word_new (NULL);
+			new_word = word_new(NULL);
 			if (!new_word)
-				error_handler ("cannot allocate word");
+				error_handler("Cannot allocate word");
 
 			/* Get the sublist */
-			new_word->child = word_read (f);
-			if (!new_word->hash_index && !new_word->child)
-			{
-				/* printf ("unable to read children!\n"); */
-			}
+			new_word->child = word_read(f);
 
 		} else if (input_str[0] == '}') {
-#if 0
-printf ("returning from word_read.\n");
-#endif
 			return first_word;
 		} else {
-			new_word = word_new (input_str);
+			new_word = word_new(input_str);
 		}
 
-		if (prev_word) prev_word->next = new_word;
+		if (prev_word)
+			prev_word->next = new_word;
 
-		if (!first_word) first_word = new_word;
+		if (!first_word)
+			first_word = new_word;
 
 		prev_word = new_word;
 
-		/* Free up the memory allocated by read_word.
-		 */
-		my_free (input_str);
+		/* Free up the memory allocated by read_word. */
+		my_free(input_str);
 		input_str = NULL;
-	}
-	while(1);
-
+	} while (1);
 }
-
-
